"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var fse = require("fs-extra");
function getCacheContent(options) {
    var compilePackages = options.compilePackages, rootDir = options.rootDir, userConfig = options.userConfig;
    var cacheKeyOfUserConfig = [
        'plugins',
        'alias',
        'compileDependencies',
        'cssLoaderOptions',
        'define',
        'externals',
        'lessLoaderOptions',
        'postcssOptions',
        'sassLoaderOptions',
        'webpackLoaders',
        'webpackPlugins'
    ];
    var cacheConfig = cacheKeyOfUserConfig.reduce(function (prev, current) {
        if (Object.prototype.hasOwnProperty.call(userConfig, current)) {
            prev.push(current + ": " + JSON.stringify(userConfig[current]));
        }
        return prev;
    }, []);
    var cachePackages = compilePackages.sort().map(function (packageName) {
        try {
            var packageJson = fse.readJSONSync(require.resolve(path.join(packageName, 'package.json'), { paths: [rootDir] }));
            return packageName + ": " + packageJson.version;
        }
        catch (err) {
            return packageName + ": false";
        }
    });
    return JSON.stringify({ config: cacheConfig, packages: cachePackages });
}
exports.default = getCacheContent;
//# sourceMappingURL=getCacheContent.js.map